@@ -1,4 +1,6 @@
 from geosolution.hexagondesign import check_topology
 from geosolution.hexagondesign import hexagon_grid
 from geosolution.hexagondesign import merge_shapefile
-from geosolution.hexagondesign import check_crs
\ No newline at end of file
+from geosolution.hexagondesign import check_crs
+from geosolution.hexagondesign import transfer_val
+from geosolution.hexagondesign import square_grid
\ No newline at end of file
